function [pl vals] = llppredict(X, model)
%
% Multi-nominal logistic regression outputs
%  [pl val] = llppredict(X, model)
%
% Input:
%  X - Sample vectors [#test x dim]
%  model - Classifier model produced by `llptrain.m'
%           .W - Coefficient vectors [dim/dim+1 x #class-1]
%                The last row indicate the bases for the case of `dim+1'.
%           .labels - Class labels for the columns [1 x #class]
%
% Output:
%  pl  - Predicted label vector [#test x 1]
%  val - Classification values  [#test x #class]
%

dim = size(X,2);

vals = X*model.W(1:dim,:);
if size(model.W,1) > dim
 	vals = bsxfun(@plus, vals, model.W(dim+1:end,:));
end

vals = logit(vals);
[~, maxind] = max(vals,[],2);
pl   = reshape(model.labels(maxind),[],1);
